<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Kasvojen tunnistus</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Vahvista kasvojen tunnistuksella</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Kasvojen tunnistus lukittu, käytä salasanaa</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Laite ei ole käytettävissä!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Vahvista sormenjälläsi</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Sormenjälki lukittu, käytä salasanaa</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iriksen tunnus</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Vahvista iriksen tunnistuksella</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iriksen tunnistus lukittu, käytä salasanaa</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>Liitä suojausavain</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>Tarkistus epäonnistui</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>Suojausavaimella tunnistaminen</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Väärä salasana</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Nollaa salasana</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Unohtuiko salasana?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Nollaa salasana</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Unohtuiko salasana?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Väärä PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey vaaditaan</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Anna PIN-koodisi</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Käyttäjätili</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Salasanasi vanhenee %n päivän kuluttua, vaihda se ajoissa</numerusform><numerusform>Salasanasi vanhenee %n päivän kuluttua, vaihda se ajoissa</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Salasana vanhentunut, vaihda</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>Salasanasi on vanhentunut. Ota yhteyttä järjestelmänvalvojaan muuttaaksesi sitä</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>Pääte on lukittu, ota yhteyttä järjestelmänvalvojaan</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Väärä tili</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Väärä salasana</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation>Estämisen syy.</translation>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>Vakiotila</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Lukitse näyttö</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Näytön lukitseminen epäonnistui</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Sormenjäljen tarkistus aikakatkaistiin, ole hyvä ja anna salasana manuaalisesti</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Sormenjälkeä ei tunnistettu</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Edellä mainitut käyttäjät ovat vielä kirjautuneet sisään ja tiedot katoavat, koska haluat sammuttaa?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Edellä mainitut käyttäjät ovat vielä kirjautuneet sisään ja tiedot katoavat uudelleenkäynnistyksen takia, haluatko varmasti uudelleenkäynnistyksen?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Olet ottanut käyttöön korkean järjestelmän suojaustason, joten et voi vaihtaa Wayland-tilaan. Poista suojaustaso Turvakeskuksesta ja yritä uudelleen.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukitse</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Vaihda käyttäjää</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Vaihda järjestelmää</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Päivitä ja sammuta</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Päivitä ja käynnistä</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Käynnistä järjestelmänhallinta</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation>Lähetä vahvistuskoodi</translation>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation>Anna puhelinnumero</translation>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation>Anna vahvistuskoodi</translation>
    </message>
    <message>
        <source>获取验证码</source>
        <translation>Hanki vahvistuskoodi</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Kytke kone sähköverkkoon ja asenna sitten päivitykset.</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation>Palaa</translation>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation>Valitse tili kirjautumiseen</translation>
    </message>
    <message>
        <source>Local Account</source>
        <translation>Paikallinen tili</translation>
    </message>
    <message>
        <source>Domain Account</source>
        <translation>Toimialueen tili</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Ohjelmat estävät tietokoneen sammutusta ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Valitse ensin Peruuta ja sulje sitten avoin ohjelma.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät käynnistyksen uudelleen ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät valmiustilan ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät lepotilan ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät kirjautumisen ulos ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Haluatko varmasti sulkea?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Haluatko käynnistää uudelleen?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Haluatko kirjautua ulos?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Päivitä ja sammuta</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Päivitä ja käynnistä</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>Suljetaan ohjelmat ja sammutetaan, odota...</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>Suljetaan ohjelmat ja käynnistetään uudelleen, odota...</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>Suljetaan ohjelmat ja kirjaudutaan ulos, odota...</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation>Kirjaudu automaattisesti</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
</context>
</TS>